@@ -261,6 +261,18 @@ class Chunk:
     def get_urls(self) -> Optional[Sequence[str]]:
         return None
 
+    @abstractmethod
+    def is_groupable(self) -> bool:
+        ...
+
+    @abstractmethod
+    def is_group(self) -> bool:
+        ...
+
+    @abstractmethod
+    def get_group(self) -> Any:
+        ...
+
 
 class YAMLChunk(Chunk):
     def __init__(
@@ -334,6 +346,16 @@ class YAMLChunk(Chunk):
         # return "yaml"
 
 
+class YAMLGroupChunk(YAMLChunk):
+    def __init__(
+        self,
+        raw_chunk: Optional[RawChunk] = None,
+        dictionary: Optional[Dict[str, Any]] = None,
+        page_variables: Optional[Dict[str, Any]] = None,
+    ):
+        super().__init__(raw_chunk, dictionary, page_variables, optional=["status"])
+
+
 class YAMLDataChunk(YAMLChunk):
     def __init__(
         self,
